<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AudioCart</name>
    <message>
        <source>Copying audio...</source>
        <translation>Copiando áudio...</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Deletar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>WT</source>
        <translation type="obsolete">WT</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">DESCRIÇÃO</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">DURAÇÃO</translation>
    </message>
    <message>
        <source>LAST PLAYED</source>
        <translation type="obsolete">ÚLTIMO VEZ EXECUTADA</translation>
    </message>
    <message>
        <source># OF PLAYS</source>
        <translation type="obsolete"># AO AR</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation type="obsolete">ORIGEM</translation>
    </message>
    <message>
        <source>OUTCUE</source>
        <translation type="obsolete">COMENTÁRIO</translation>
    </message>
    <message>
        <source>START DATE</source>
        <translation type="obsolete">DATA DE INÍCIO</translation>
    </message>
    <message>
        <source>END DATE</source>
        <translation type="obsolete">DATA DE TÉRMINO</translation>
    </message>
    <message>
        <source>DAYPART START</source>
        <translation type="obsolete">DIAS PERMITIDOS INÍCIO</translation>
    </message>
    <message>
        <source>DAYPART END</source>
        <translation type="obsolete">DIAS PERMITIDOS TÉRMINO</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="obsolete">NOME</translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation type="obsolete">Conteúdos</translation>
    </message>
    <message>
        <source>Cut Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Edit
Audio</source>
        <translation>Editar
Áudio</translation>
    </message>
    <message>
        <source>Edit
Markers</source>
        <translation>Editar
Marcadores</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Rip CD</source>
        <translation>Extrair CD</translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation>Tem certeza que quer deletar</translation>
    </message>
    <message>
        <source>Delete Cut</source>
        <translation>Deletar Conteúdo</translation>
    </message>
    <message>
        <source>RDCatch Event Exists</source>
        <translation>Evento de RDCaptura existente</translation>
    </message>
    <message>
        <source>This cut is used in one or more RDCatch events!
Do you still want to delete it?</source>
        <translation type="obsolete">Este Conteúdo é usado em um ou mais Eventos do RDCaptura
Você quer deletá-lo mesmo assim?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Esvaziar Clipboard</translation>
    </message>
    <message>
        <source>Deleting this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Delatar este Conteúdo também esvaziará o clipboard.
Você ainda quer proceder?</translation>
    </message>
    <message>
        <source>Clipboard Empty</source>
        <translation>Clipboard Vazio</translation>
    </message>
    <message>
        <source>Clipboard is currently empty.</source>
        <translation>Clipboard está vazio.</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>Áudio Existe</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Esta ação sobrescreverá a gravação existente.
Você quer proceder?</translation>
    </message>
    <message>
        <source>[new cart]</source>
        <translation>[novo cartão]</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>1 Cut</source>
        <translation type="obsolete">1 Conteúdo</translation>
    </message>
    <message>
        <source>RDLibrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No audio is present in the cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One or more cuts are used in one or more RDCatch events!
Do you still want to delete?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete audio for cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No data copied - you must select a single cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must select a single cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Played</source>
        <translation type="unfinished">Última vez Executada</translation>
    </message>
    <message>
        <source># of Plays</source>
        <translation type="unfinished"># Ao Ar</translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ingest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outcue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daypart Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daypart End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ord</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CdRipper</name>
    <message>
        <source>Artist:</source>
        <translation>Artista:</translation>
    </message>
    <message>
        <source>Album:</source>
        <translation>Álbum:</translation>
    </message>
    <message>
        <source>Other:</source>
        <translation>Outro:</translation>
    </message>
    <message>
        <source>Apply FreeDB Values to Cart</source>
        <translation type="obsolete">Aplicar Valores do FreeDB ao Cartão</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Faixas</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>FAIXAS</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>DURAÇÃO</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TÍTULO</translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation>OUTRO</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TIPO</translation>
    </message>
    <message>
        <source>&amp;Rip
Track</source>
        <translation>&amp;Extrair
Faixa</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizar</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nível</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>AutoCorte</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Canais:</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>Áudio Existe</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Esta ação sobrescreverá a gravação existente.
Você quer proceder?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Esvaziar Clipboard</translation>
    </message>
    <message>
        <source>Ripping this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Extrair este Conteúdo também esvaziará o clipboard.
Você ainda quer proceder?</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Sem Acesso</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">Não foi possível abrir o arquivo para escrita!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Audio Track</source>
        <translation>Faixa de Áudio</translation>
    </message>
    <message>
        <source>Data Track</source>
        <translation>Faixa de Dados</translation>
    </message>
    <message>
        <source>Rip Complete</source>
        <translation>Extração Completa</translation>
    </message>
    <message>
        <source>Rip complete!</source>
        <translation>Extração Completa!</translation>
    </message>
    <message>
        <source>Rip Aborted</source>
        <translation type="obsolete">Extração Abortada</translation>
    </message>
    <message>
        <source>The rip has been aborted.</source>
        <translation type="obsolete">A Extração foi abortada</translation>
    </message>
    <message>
        <source>Rip Failed</source>
        <translation type="obsolete">Extração falhou</translation>
    </message>
    <message>
        <source>The ripper encountered an error.
Please check your ripper configuration and try again.</source>
        <translation type="obsolete">O dispositivo de extração encontrou um Erro.
Por Favor, cheque suas configurações e tente novamente.</translation>
    </message>
    <message>
        <source>Abort
Rip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Importer Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip CD</source>
        <translation type="unfinished">Extrair CD</translation>
    </message>
    <message>
        <source>Rip
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Values to Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lookup Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DiskGauge</name>
    <message>
        <source>Free</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DiskRipper</name>
    <message>
        <source>Rip Disk</source>
        <translation>Extrair Disco</translation>
    </message>
    <message>
        <source>Artist:</source>
        <translation>Artista:</translation>
    </message>
    <message>
        <source>Album:</source>
        <translation>Álbum:</translation>
    </message>
    <message>
        <source>Other:</source>
        <translation>Outro:</translation>
    </message>
    <message>
        <source>Apply FreeDB Values to Carts</source>
        <translation type="obsolete">Aplicar Valores do FreeDB ao Cartão</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Faixas</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>FAIXA</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>DURAÇÃO</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TÍTULO</translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation>OUTRO</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TIPO</translation>
    </message>
    <message>
        <source>CUT</source>
        <translation>CONTEÚDO</translation>
    </message>
    <message>
        <source>Disk Progress</source>
        <translation>Progresso do Disco</translation>
    </message>
    <message>
        <source>Track Progress</source>
        <translation>Progresso da Faixa</translation>
    </message>
    <message>
        <source>Set
&amp;Cut</source>
        <translation type="obsolete">Selecionar
&amp;Conteúdo</translation>
    </message>
    <message>
        <source>Set All
&amp;New Carts</source>
        <translation type="obsolete">Sel Todos
&amp;Cartões</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizar</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nível:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>AutoCorte</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Canais:</translation>
    </message>
    <message>
        <source>&amp;Rip
Disk</source>
        <translation type="obsolete">&amp;Extrair 
Disco</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>Cut Conflict</source>
        <translation>Confllito de Conteúdo</translation>
    </message>
    <message>
        <source>That cut has already been assigned a track!</source>
        <translation>Este conteúdo já foi destinado a uma faixa!</translation>
    </message>
    <message>
        <source>Cut Exists</source>
        <translation>COnteúdo Existente</translation>
    </message>
    <message>
        <source>A recording already exists.
Do you want to overwrite it?</source>
        <translation>Uma gravação já existe.
Você quer sobrescrevê-la?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Esvaziar Clipboard</translation>
    </message>
    <message>
        <source>Ripping this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Extrair este Conteúdo também esvaziará o clipboard.
Você ainda quer proceder?</translation>
    </message>
    <message>
        <source>Library Error</source>
        <translation type="obsolete">Erro na Biblioteca</translation>
    </message>
    <message>
        <source>Insufficient free carts available in group!</source>
        <translation type="obsolete">Cartão vazios insuficientes neste grupo!</translation>
    </message>
    <message>
        <source>Audio Track</source>
        <translation>Faixa de Áudio</translation>
    </message>
    <message>
        <source>Data Track</source>
        <translation>Faixa de Dados</translation>
    </message>
    <message>
        <source>Rip Complete</source>
        <translation>Extração Completa</translation>
    </message>
    <message>
        <source>Rip complete!</source>
        <translation>Extração Completa!</translation>
    </message>
    <message>
        <source>Rip Aborted</source>
        <translation type="obsolete">Extração Abortada</translation>
    </message>
    <message>
        <source>The rip has been aborted.</source>
        <translation type="obsolete">A Extração foi abortada</translation>
    </message>
    <message>
        <source>Rip Failed</source>
        <translation type="obsolete">Extração falhou</translation>
    </message>
    <message>
        <source>The ripper encountered an error.
Please check your ripper configuration and try again.</source>
        <translation type="obsolete">O dispositivo de extração encontrou um Erro.
Por Favor, cheque suas configurações e tente novamente.</translation>
    </message>
    <message>
        <source>Total Progress</source>
        <translation>Progresso Total</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Sem Acesso</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">Não foi possível abrir o arquivo para escrita!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>&amp;Rip
Disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort
Rip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip
Disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip aborted!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Importer Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Cart
Per Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Single
Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set
&amp;Cart/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[continued]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify
Cart Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear
Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to allocate carts in group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to allocate cart in group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Values to Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lookup Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditCart</name>
    <message>
        <source>Number:</source>
        <translation>Número:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Average Length:</source>
        <translation>Duração Média:</translation>
    </message>
    <message>
        <source>Enforce Length</source>
        <translation>Forçar Duração</translation>
    </message>
    <message>
        <source>Forced Length:</source>
        <translation>Duração Forçada:</translation>
    </message>
    <message>
        <source>Preserve Pitch</source>
        <translation>Preservar Pitch</translation>
    </message>
    <message>
        <source>&amp;Title:</source>
        <translation>&amp;Título</translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation>&amp;Data de Início:</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation>&amp;Data de Término:</translation>
    </message>
    <message>
        <source>&amp;Artist:</source>
        <translation>&amp;Artista:</translation>
    </message>
    <message>
        <source>&amp;Year Released:</source>
        <translation>&amp;Ano de Lançamento:</translation>
    </message>
    <message>
        <source>U&amp;sage:</source>
        <translation>&amp;Uso:</translation>
    </message>
    <message>
        <source>Scheduler Codes</source>
        <translation>Códigos do Agendador</translation>
    </message>
    <message>
        <source>Al&amp;bum:</source>
        <translation>&amp;Álbum:</translation>
    </message>
    <message>
        <source>Re&amp;cord Label:</source>
        <translation>Gravadora/Selo:</translation>
    </message>
    <message>
        <source>C&amp;lient:</source>
        <translation>&amp;Cliente:</translation>
    </message>
    <message>
        <source>A&amp;gency:</source>
        <translation>&amp;Agência</translation>
    </message>
    <message>
        <source>&amp;Publisher:</source>
        <translation>&amp;Editora:</translation>
    </message>
    <message>
        <source>Compos&amp;er:</source>
        <translation>&amp;Compositor:</translation>
    </message>
    <message>
        <source>&amp;User Defined:</source>
        <translation>&amp;Uso Genérico:</translation>
    </message>
    <message>
        <source>Schedule Cuts:</source>
        <translation type="obsolete">Agendar Conteúdos:</translation>
    </message>
    <message>
        <source>Execute Asynchronously</source>
        <translation>Executar sem Sincronia</translation>
    </message>
    <message>
        <source>&amp;Edit
Notes</source>
        <translation>&amp;Editar
Notas</translation>
    </message>
    <message>
        <source>&amp;Edit
Script</source>
        <translation>&amp;Editar
Script</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>AUDIO</source>
        <translation>ÁUDIO</translation>
    </message>
    <message>
        <source>MACRO</source>
        <translation>MACRO</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation>DESCONHECIDO</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation>TFN</translation>
    </message>
    <message>
        <source>Sequentially</source>
        <translation type="obsolete">Sequencialmente</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="obsolete">Randomicamente</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Missing Title</source>
        <translation>Sem Título</translation>
    </message>
    <message>
        <source>You must provide at least a Cart Title!</source>
        <translation>Você deve dar no mínimo um título ao Cartão!</translation>
    </message>
    <message>
        <source>Duplicate Title</source>
        <translation>Duplicar Título </translation>
    </message>
    <message>
        <source>The cart title must be unique!</source>
        <translation>O Título do Cartão deve ser Único!</translation>
    </message>
    <message>
        <source>Length Mismatch</source>
        <translation>Duração Desencontrada</translation>
    </message>
    <message>
        <source>One or more cut lengths exceed the timescaling
limits of the system!  Do you still want to save?</source>
        <translation>Uma ou mais durações de Conteúdos excedem a escala de tempo
limite do sistema!   Você ainda quer salvar?</translation>
    </message>
    <message>
        <source>RDLibrary - Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cond&amp;uctor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Song &amp;ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Beats per Minute:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By Specified Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schedule Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following cut order values are assigned more than once</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Cut Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Carts [multiple]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use RDLogManager Length for PAD Updates</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMacro</name>
    <message>
        <source>Edit Macro</source>
        <translation type="obsolete">Editar Macro</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>EditNotes</name>
    <message>
        <source>Notes for cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>EditSchedulerCodes</name>
    <message>
        <source>Select Scheduler Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assigned Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ASSIGN to Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>REMOVE from Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Library Filter</source>
        <translation type="obsolete">Filtro </translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation type="obsolete">&amp;Limpar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Cancelar</translation>
    </message>
    <message>
        <source>&amp;Filter:</source>
        <translation type="obsolete">&amp;Filtrar:</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>Cart Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished">Tipo:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Fechar</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished">TODOS</translation>
    </message>
    <message>
        <source>Cart Data Dump (CSV)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prepend Field Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MacroCart</name>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Deletar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>LINE</source>
        <translation type="obsolete">LINHA</translation>
    </message>
    <message>
        <source>COMMAND</source>
        <translation type="obsolete">COMANDO</translation>
    </message>
    <message>
        <source>Macros</source>
        <translation>Macros</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Run
Line</source>
        <translation>Executar
Linha</translation>
    </message>
    <message>
        <source>Run
Cart</source>
        <translation>Executar
Cartão</translation>
    </message>
    <message>
        <source>--- End of cart ---</source>
        <translation type="obsolete">-- Fim do Cartão --</translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--- End of Cart ---</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Please Wait...</source>
        <translation>Por favor, espere...</translation>
    </message>
    <message>
        <source>rdlibrary : </source>
        <translation type="obsolete">RDBiblio: </translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Sem conexão</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Procura</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Limpe</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation>Códigos:</translation>
    </message>
    <message>
        <source>Show Audio Carts</source>
        <translation>Mostrar Áudio</translation>
    </message>
    <message>
        <source>Show Macro Carts</source>
        <translation></translation>
    </message>
    <message>
        <source>Show Note Bubbles</source>
        <translation>Mostrar Notas </translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">CARTÃO</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">GRUPO</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">DURAÇÃO</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">TÍTULO</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">ARTISTA</translation>
    </message>
    <message>
        <source>START</source>
        <translation type="obsolete">INÍCIO</translation>
    </message>
    <message>
        <source>END</source>
        <translation type="obsolete">FIM</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="obsolete">CLIENTE</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="obsolete">AGÊNCIA</translation>
    </message>
    <message>
        <source>USER DEFINED</source>
        <translation type="obsolete">USO GENÉRICO</translation>
    </message>
    <message>
        <source>CUTS</source>
        <translation type="obsolete">CONTEÚDOS</translation>
    </message>
    <message>
        <source>LAST CUT PLAYED</source>
        <translation type="obsolete">ÚLTIMO CONTEÚDO EXECUTADO</translation>
    </message>
    <message>
        <source>PLAY ORDER</source>
        <translation type="obsolete">ORDEM DE EXECUÇÃO</translation>
    </message>
    <message>
        <source>ENFORCE LENGTH</source>
        <translation type="obsolete">FORÇAR DURAÇÃO</translation>
    </message>
    <message>
        <source>PRESERVE PITCH</source>
        <translation type="obsolete">PRESERVAR PITCH</translation>
    </message>
    <message>
        <source>LENGTH DEVIATION</source>
        <translation type="obsolete">DESVIO DE DURAÇÃO</translation>
    </message>
    <message>
        <source>OWNED BY</source>
        <translation type="obsolete">DONO</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Deletar</translation>
    </message>
    <message>
        <source>&amp;Rip
CD</source>
        <translation>&amp;Extrair
CD</translation>
    </message>
    <message>
        <source>Re&amp;ports</source>
        <translation>&amp;Relatórios</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>TODOS</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Are you sure you want to delete cart(s)</source>
        <translation>Tem certeza que quer deletar cartão(s)</translation>
    </message>
    <message>
        <source>Delete Cart(s)</source>
        <translation>Deletar Cartão(s)</translation>
    </message>
    <message>
        <source>Cart %06u is used in one or more RDCatch events!
Do you still want to delete it?</source>
        <translation>Cartão %06u é usado em um ou mais eventos do RDCaptura!
Você ainda quer deletá-lo?</translation>
    </message>
    <message>
        <source>RDCatch Event Exists</source>
        <translation>Evento do RDCaptura Existente</translation>
    </message>
    <message>
        <source>Deleting cart %06u will also empty the clipboard.
      	Do you still want to proceed?</source>
        <translation>Deletar o Cartão %06u também esvaziará o clipboard.
      	Você ainda quer proceder?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Esvaziar Clipboard</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation type="obsolete">Sequência</translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="obsolete">Randômico</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation>TFN</translation>
    </message>
    <message>
        <source>RDLibrary - Host:</source>
        <translation type="obsolete">RDBiblio - Cliente:</translation>
    </message>
    <message>
        <source>, User:</source>
        <translation type="obsolete">, Usuário:</translation>
    </message>
    <message>
        <source>Show Only First </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Matches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete audio!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow Cart Dragging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Término</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Composer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conductor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Publisher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Defined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation type="unfinished">Conteúdos</translation>
    </message>
    <message>
        <source>Last Cut Played</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enforce Length</source>
        <translation type="unfinished">Forçar Duração</translation>
    </message>
    <message>
        <source>Preserve Pitch</source>
        <translation type="unfinished">Preservar Pitch</translation>
    </message>
    <message>
        <source>Length Deviation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Owned By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Talk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run
&amp;Macro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>And Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matching Carts:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecordCut</name>
    <message>
        <source>RDLibrary - Record</source>
        <translation type="obsolete">RDBiblio - Gravacão</translation>
    </message>
    <message>
        <source>&amp;Description</source>
        <translation>&amp;Descrição</translation>
    </message>
    <message>
        <source>&amp;Outcue</source>
        <translation>&amp;Comentário</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation type="obsolete">Origem</translation>
    </message>
    <message>
        <source>ISRC</source>
        <translation>ISRC</translation>
    </message>
    <message>
        <source>Weight</source>
        <translation>Peso</translation>
    </message>
    <message>
        <source>Last Played</source>
        <translation>Última vez Executada</translation>
    </message>
    <message>
        <source># of Plays</source>
        <translation># Ao Ar</translation>
    </message>
    <message>
        <source>Cut is EVERGREEN</source>
        <translation>Conteúdo sempre PERMITIDO</translation>
    </message>
    <message>
        <source>Air Date/Time</source>
        <translation>Hora/Data Ar</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Habilitado</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desabilitado</translation>
    </message>
    <message>
        <source>&amp;Start</source>
        <translation>&amp;Início</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Término</translation>
    </message>
    <message>
        <source>Daypart</source>
        <translation>Hora Ar</translation>
    </message>
    <message>
        <source>&amp;Start Time</source>
        <translation>&amp;Início</translation>
    </message>
    <message>
        <source>End Time</source>
        <translation>Término</translation>
    </message>
    <message>
        <source>Day of the Week</source>
        <translation>Dias da Semana</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Segunda</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Terça</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Quarta</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Quinta</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Sexta</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Set All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>NO SYNC!</source>
        <translation type="obsolete">SEM SINCRONIA!</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <source>Record Mode</source>
        <translation>Gravação</translation>
    </message>
    <message>
        <source>AutoTrim</source>
        <translation>AutoCorte</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>VOX</source>
        <translation>VOZ</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Ligado</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>Áudio Existe</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Esta ação sobrescreverá a gravação existente.
Você quer proceder?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Esvaziar Clipboard</translation>
    </message>
    <message>
        <source>This will empty the clipboard.
Do you still want to proceed?</source>
        <translation>Esta Ação esvaziará o clipboard.
Você ainda quer proceder?</translation>
    </message>
    <message>
        <source>Missing Description</source>
        <translation>Descrição Faltante</translation>
    </message>
    <message>
        <source>You must provide a Cut Description!</source>
        <translation>Você deve dar descrição ao Conteúdo!</translation>
    </message>
    <message>
        <source>Invalid ISRC</source>
        <translation>ISRC Inválido</translation>
    </message>
    <message>
        <source>The ISRC data is malformed or invalid!</source>
        <translation>Os dados de ISRC está mal formado ou inválido!</translation>
    </message>
    <message>
        <source>Invalid Date</source>
        <translation>Data Inválida</translation>
    </message>
    <message>
        <source>The Start Date is invalid!</source>
        <translation>A Data de Início é inválida!</translation>
    </message>
    <message>
        <source>The End Date is invalid!</source>
        <translation>A Data de Término é inválida!</translation>
    </message>
    <message>
        <source>The End Date is prior to the Start Date!</source>
        <translation>A Data de Término deve vir antes da Data de início!</translation>
    </message>
    <message>
        <source>The End Date has already passed!
Do you still want to save?</source>
        <translation>A Data de Teŕmino já se passou!
Você ainda quer salvar?</translation>
    </message>
    <message>
        <source>Invalid Time</source>
        <translation>Hora Inválida</translation>
    </message>
    <message>
        <source>The Start Time is invalid!</source>
        <translation>A Hora de Início é inválida!</translation>
    </message>
    <message>
        <source>The End Time is invalid!</source>
        <translation>A Hora de Término é inválida!</translation>
    </message>
    <message>
        <source>The StartTime cannot be the same as the End Time!</source>
        <translation>A Hora de início não pode ser a mesma que a Hora de Término!</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Não foi possível Conectar</translation>
    </message>
    <message>
        <source>Unable to connect to Core AudioEngine</source>
        <translation>Não foi possível conectar ao Sistema de Áudio</translation>
    </message>
    <message>
        <source>&amp;ISCI Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AES ALARM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ingest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Info / Record</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
